DllInjection

Struct DllInjection 

pub struct DllInjection<D: DllApp> { /* private fields */ }
Available on crate feature inject-dll only.
Represents an injected DLL with its syringe, payload, and remote apply function.

Implementations

Source

impl<D: DllApp> DllInjection<D>

pub fn pid(&self) -> Pid

pub fn maybe_apply( &self, input: Option<&D::Input>, ) -> Result<D::Output, PayloadRpcError>

Call DllApp::APPLY with the given input.

pub fn apply(&self, input: &D::Input) -> Result<D::Output, PayloadRpcError>

Call DllApp::APPLY with the given input.

Implementation
let args = (input,);
let config = bincode::config::standard();

let mut size_writer = bincode::enc::write::SizeWriter::default();
bincode::serde::encode_into_writer(&args, &mut size_writer, config)?;
let arg_bytes = size_writer.bytes_written;
let mut local_arg_buf = Vec::with_capacity(arg_bytes);
bincode::serde::encode_into_std_write(&args, &mut local_arg_buf, config)?;
unsafe { local_arg_buf.set_len(arg_bytes) };
// println!("{:02X?}", local_arg_buf);

/*
let buf = &local_arg_buf[..arg_bytes].to_owned();
println!("decode_from_slice {:02X?}", buf);
let args: Result<((Option<Input>,), usize), bincode::error::DecodeError> =
    bincode::serde::decode_from_slice::<(Option<Input>,), _>(buf, config);
println!("{:?}", args);
*/
...
pub fn unapply(&self) -> Result<D::Output, PayloadRpcError>

pub fn eject(&mut self) -> Result<(), InjectError>

Eject the DLL from the target process.

This will first unapply if it was applied before.

pub fn leak(&mut self)

Leak the injection, preventing both manual and automatic eject().

pub fn inject<'f1, 'f2>( process: OwnedProcess, ) -> DllInjectionInjectBuilder<'f1, 'f2, D>

Inject the DLL into the given process and optionally appliy it (call APPLY()).