DllInjectionVec

Struct DllInjectionVec 

pub struct DllInjectionVec<D: DllApp> { /* private fields */ }
Available on crate feature inject-dll only.
A collection of injected processes that can be ejected together.

Implementations

Source

impl<D: DllApp> DllInjectionVec<D>

pub fn new() -> Self

pub fn injections(&self) -> &[DllInjection<D>]

pub fn injections_mut(&mut self) -> &mut [DllInjection<D>]

pub fn leak(&mut self)

Leak existing and new injections, preventing automatic cleanup on drop. (Unlike DllInjection::leak, this doesn’t prevent manual eject())

pub fn inject<'f1, 'f2, 'f3, I1, I2>( &'f1 mut self, processes: I1, ) -> DllInjectionVecInjectBuilder<'f1, 'f2, 'f3, D, I1, I2>
where I1: Iterator<Item = OwnedProcess>, I2: FnMut(Pid, InjectError),

Inject the DLL into the given processes.

Before DllInjectionVec::eject(), the DLL file will be locked and can’t be deleted.

Returns
  • Ok(DllInjectionVec): Successfully injected processes
  • Err(InjectError): Error during injection
pub fn inject_with_process_name<'f1, 'f2, 'f3, 'f4, I1>( &'f1 mut self, process_name: &'f2 str, ) -> DllInjectionVecInjectWithProcessNameBuilder<'f1, 'f2, 'f3, 'f4, D, I1>
where I1: FnMut(Pid, InjectError),

Inject the DLL into all processes with the given name.

Before DllInjectionVec::eject(), the DLL file will be locked and can’t be deleted.

Returns
  • Ok(DllInjectionVec): Successfully injected processes
  • Err(InjectError): Error during injection
pub fn apply<'f1, 'f2, I1>( &'f1 self, input: &'f2 D::Input, ) -> DllInjectionVecApplyBuilder<'f1, 'f2, D, I1>
where I1: FnMut(Pid, &PayloadRpcError),

Call apply on all injections.

Errors are reported via the on_error callback.

pub fn unapply<'f1, I1>(&'f1 self) -> DllInjectionVecUnapplyBuilder<'f1, D, I1>
where I1: FnMut(Pid, &PayloadRpcError),

Call unapply on all injections.

Errors are reported via the on_error callback.

pub fn eject<'f1, I1>(&'f1 mut self) -> DllInjectionVecEjectBuilder<'f1, D, I1>
where I1: FnMut(Pid, InjectError),

Eject all DLL injections.