OwnedProcess

Struct OwnedProcess 

pub struct OwnedProcess(/* private fields */);
Available on crate feature inject-dll only.
A struct representing a running process. This struct owns the underlying process handle (see also BorrowedProcess for a borrowed version).

Note

The underlying handle has the following privileges:

  • PROCESS_CREATE_THREAD
  • PROCESS_QUERY_INFORMATION
  • PROCESS_VM_OPERATION
  • PROCESS_VM_WRITE
  • PROCESS_VM_READ

Implementations

Source

impl OwnedProcess

pub fn from_pid(pid: u32) -> Result<OwnedProcess, Error>

Creates a new instance from the given pid.

pub fn all() -> Vec<OwnedProcess>

Returns a list of all currently running processes.

pub fn find_all_by_name(name: impl AsRef<str>) -> Vec<OwnedProcess>

Finds all processes whose name contains the given string.

pub fn find_first_by_name(name: impl AsRef<str>) -> Option<OwnedProcess>

Finds the first process whose name contains the given string.

pub fn from_child(child: Child) -> OwnedProcess

Creates a new instance from the given child process.

pub unsafe fn borrowed_static(&self) -> BorrowedProcess<'static>

Returns a borrowed instance of this process that lives for 'static.

Safety
  • This method is unsafe as the returned instance can outlive the owned instance, thus the caller must guarantee that the owned instance outlives the returned instance.
pub fn try_clone(&self) -> Result<OwnedProcess, Error>

Creates a new owning Process instance for this process by duplicating the underlying handle.

pub fn leak(self) -> BorrowedProcess<'static>

Leaks the underlying handle and return it as a non-owning BorrowedProcess instance.

pub const fn kill_on_drop(self) -> ProcessKillGuard

Returns a ProcessKillGuard wrapping this process that will automatically kill this process when dropped.