pub enum GuiProcessEvent {
CreateOrAlive(Pid),
Alive(Pid),
}Expand description
Event types for GUI process monitoring.
These events are triggered by shell hook messages that indicate GUI process activity.
- For a process started after the watcher,
CreateOrAlivemust occur beforeAlivewith the same PID.
Variants
CreateOrAlive(Pid)
A new GUI process has been created, or an existing process is detected.
Alive(Pid)
An existing GUI process is detected.
Implementations