Struct Module
Source #[repr(transparent)]
pub struct Module(pub HMODULE);
A process module (EXE/DLL).
Get the handle of the current executable or DLL.
Ref: https://github.com/compio-rs/winio/issues/35
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
The resulting type after dereferencing.
Dereferences the value.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
The DropFlavor that
wraps
T into
Self
Returns the argument unchanged.
A constant of the type witness
Proof that Self is the same type as Self::Type,
provides methods for casting between Self and Self::Type.
The same type as Self,
used to emulate type equality bounds (T == U)
with associated type equality constraints
(T: Identity<Type = U>).
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.