GuiProcessWatcherForEachBuilder

Struct GuiProcessWatcherForEachBuilder 

pub struct GuiProcessWatcherForEachBuilder<I1, I2, S: State = Empty>
where I1: FnMut(Pid) + Send + 'static, I2: FnMut(Option<&Path>) -> bool + Send + 'static,
{ /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<I1, I2, S: State> GuiProcessWatcherForEachBuilder<I1, I2, S>
where I1: FnMut(Pid) + Send + 'static, I2: FnMut(Option<&Path>) -> bool + Send + 'static,

pub fn build(self) -> Result<GuiProcessWatcher>
where S: IsComplete,

Finishes building and performs the requested action.

pub fn filter_image_path( self, value: I2, ) -> GuiProcessWatcherForEachBuilder<I1, I2, SetFilterImagePath<S>>
where S::FilterImagePath: IsUnset,

Required.

pub fn create_only( self, value: bool, ) -> GuiProcessWatcherForEachBuilder<I1, I2, SetCreateOnly<S>>
where S::CreateOnly: IsUnset,

Optional (Some / Option setters). Default: true.

Mitigate TOCTOU issue further at the cost of some system performance.

pub fn maybe_create_only( self, value: Option<bool>, ) -> GuiProcessWatcherForEachBuilder<I1, I2, SetCreateOnly<S>>
where S::CreateOnly: IsUnset,

Optional (Some / Option setters). Default: true.

Mitigate TOCTOU issue further at the cost of some system performance.