GuiProcessWatcherWithFilterDedupBuilder

Struct GuiProcessWatcherWithFilterDedupBuilder 

pub struct GuiProcessWatcherWithFilterDedupBuilder<I1, I2, S: State = Empty>
where I1: GuiProcessCallback, I2: FnMut(GuiProcessEvent) -> bool + Send + 'static,
{ /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<I1, I2, S: State> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, S>
where I1: GuiProcessCallback, I2: FnMut(GuiProcessEvent) -> bool + Send + 'static,

pub fn build(self) -> Result<GuiProcessWatcher>
where S: IsComplete,

Finishes building and performs the requested action.

pub fn create_only( self, value: bool, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetCreateOnly<S>>
where S::CreateOnly: IsUnset,

Optional (Some / Option setters). Default: false.

pub fn maybe_create_only( self, value: Option<bool>, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetCreateOnly<S>>
where S::CreateOnly: IsUnset,

Optional (Some / Option setters). Default: false.

pub fn filter( self, value: I2, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetFilter<S>>
where S::Filter: IsUnset,

Required.

pub fn start_time_filter( self, value: SystemTime, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetStartTimeFilter<S>>
where S::StartTimeFilter: IsUnset,

Optional (Some / Option setters).

pub fn maybe_start_time_filter( self, value: Option<SystemTime>, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetStartTimeFilter<S>>
where S::StartTimeFilter: IsUnset,

Optional (Some / Option setters).

pub fn existing_processes( self, value: HashMap<Pid, SystemTime>, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetExistingProcesses<S>>
where S::ExistingProcesses: IsUnset,

Optional (Some / Option setters). Call callback with every process and skip them afterwards.

pub fn maybe_existing_processes( self, value: Option<HashMap<Pid, SystemTime>>, ) -> GuiProcessWatcherWithFilterDedupBuilder<I1, I2, SetExistingProcesses<S>>
where S::ExistingProcesses: IsUnset,

Optional (Some / Option setters). Call callback with every process and skip them afterwards.