ShellHookMessage

Enum ShellHookMessage 

pub enum ShellHookMessage {
Show 18 variants WindowCreated(HWND), WindowDestroyed(HWND), ActivateShellWindow, WindowActivated(HWND), RudeAppActivated(HWND), GetMinRect(HWND, RECT), TaskMan(LPARAM), Language(HWND), SysMenu(LPARAM), EndTask(HWND), AccessibilityState(LPARAM), Redraw(HWND), Flash(HWND), AppCommand(LPARAM), WindowReplaced(HWND), WindowReplacing(HWND), MonitorChanged(HWND), Unknown(WPARAM, LPARAM),
}
Shell hook message variants.

These correspond to the shell hook messages sent via [RegisterShellHookWindow].

Ref:

Variants



WindowCreated(HWND)

A top-level, unowned window has been created. The window exists when the system calls this hook.

A handle to the window being created.



WindowDestroyed(HWND)

A top-level, unowned window is about to be destroyed. The window still exists when the system calls this hook.

A handle to the top-level window being destroyed.



ActivateShellWindow

The shell should activate its main window.



WindowActivated(HWND)

The activation has changed to a different top-level, unowned window.

A handle to the activated window.



RudeAppActivated(HWND)

The activation has changed to a different top-level, unowned window in full-screen mode.

A handle to the activated window.

Ref: c# - Does anybody know what means ShellHook message HSHELL_RUDEAPPACTIVATED? - Stack Overflow



GetMinRect(HWND, RECT)

A window is being minimized or maximized. The system needs the coordinates of the minimized rectangle for the window.

  • A handle to the minimized or maximized window.
  • A pointer to a RECT structure.


TaskMan(LPARAM)

The user has selected the task list. A shell application that provides a task list should return TRUE to prevent Windows from starting its task list.

The param can be ignored.



Language(HWND)

Keyboard language was changed or a new keyboard layout was loaded.

  • A handle to the window.
  • A handle to a keyboard layout.

May require DLL hook.



SysMenu(LPARAM)

May require DLL hook.



EndTask(HWND)

A handle to the window that should be forced to exit.



AccessibilityState(LPARAM)

The accessibility state has changed.

Indicates which accessibility feature has changed state. This value is one of the following: ACCESS_FILTERKEYS, ACCESS_MOUSEKEYS, or ACCESS_STICKYKEYS.

May require DLL hook.



Redraw(HWND)

The title of a window in the task bar has been redrawn.

A handle to the window that needs to be redrawn.



Flash(HWND)

A handle to the window that needs to be flashed.



AppCommand(LPARAM)

The user completed an input event (for example, pressed an application command button on the mouse or an application command key on the keyboard), and the application did not handle the [WM_APPCOMMAND] message generated by that input.

  • The [APPCOMMAND] which has been unhandled by the application or other hooks.


WindowReplaced(HWND)

A top-level window is being replaced. The window exists when the system calls this hook.

A handle to the window being replaced.



WindowReplacing(HWND)

A handle to the window replacing the top-level window.



MonitorChanged(HWND)

A handle to the window that moved to a different monitor.



Unknown(WPARAM, LPARAM)

Unknown shell hook message.