pub struct OwnedProcess(/* private fields */);inject-dll only.Expand description
A struct representing a running process.
This struct owns the underlying process handle (see also BorrowedProcess for a borrowed version).
Note
The underlying handle has the following privileges:
PROCESS_CREATE_THREADPROCESS_QUERY_INFORMATIONPROCESS_VM_OPERATIONPROCESS_VM_WRITEPROCESS_VM_READ
Implementations
Sourceimpl OwnedProcess
impl OwnedProcess
Sourcepub fn from_pid(pid: u32) -> Result<OwnedProcess, Error>
pub fn from_pid(pid: u32) -> Result<OwnedProcess, Error>
Creates a new instance from the given pid.
Sourcepub fn all() -> Vec<OwnedProcess>
pub fn all() -> Vec<OwnedProcess>
Returns a list of all currently running processes.
Sourcepub fn find_all_by_name(name: impl AsRef<str>) -> Vec<OwnedProcess>
pub fn find_all_by_name(name: impl AsRef<str>) -> Vec<OwnedProcess>
Finds all processes whose name contains the given string.
Sourcepub fn find_first_by_name(name: impl AsRef<str>) -> Option<OwnedProcess>
pub fn find_first_by_name(name: impl AsRef<str>) -> Option<OwnedProcess>
Finds the first process whose name contains the given string.
Sourcepub fn from_child(child: Child) -> OwnedProcess
pub fn from_child(child: Child) -> OwnedProcess
Creates a new instance from the given child process.
Sourcepub unsafe fn borrowed_static(&self) -> BorrowedProcess<'static>
pub unsafe fn borrowed_static(&self) -> BorrowedProcess<'static>
Returns a borrowed instance of this process that lives for 'static.
Safety
- This method is unsafe as the returned instance can outlive the owned instance, thus the caller must guarantee that the owned instance outlives the returned instance.
Sourcepub fn try_clone(&self) -> Result<OwnedProcess, Error>
pub fn try_clone(&self) -> Result<OwnedProcess, Error>
Creates a new owning Process instance for this process by duplicating the underlying handle.
Sourcepub fn leak(self) -> BorrowedProcess<'static>
pub fn leak(self) -> BorrowedProcess<'static>
Leaks the underlying handle and return it as a non-owning BorrowedProcess instance.
Sourcepub const fn kill_on_drop(self) -> ProcessKillGuard
pub const fn kill_on_drop(self) -> ProcessKillGuard
Returns a ProcessKillGuard wrapping this process that will automatically kill this process when dropped.